Files
StarPilot/tinygrad_repo/test/external/external_cl_half_max.py
T
firestar5683 14bead366a Revert "Compile FrogPilot"
This reverts commit 255c89c6ab.
2025-09-29 10:33:41 -05:00

14 lines
370 B
Python

from tinygrad.runtime.ops_gpu import CLDevice, CLProgram, compile_cl
if __name__ == "__main__":
dev = CLDevice()
lib = compile_cl("""
#pragma OPENCL EXTENSION cl_khr_fp16 : enable
__kernel void test(__global half *out, __global half *a, __global half *b) {
int gid = get_global_id(0);
out[gid] = max(a[gid], b[gid]);
}
""")
prg = CLProgram(dev, "test", lib)